==> qt-creator-opensource-src-19.0.0-beta1.zip: qt-creator-opensource-src-19.0.0-beta1/src/plugins/qmldesigner/components/propertyeditor/propertyeditordynamicpropertiesproxymodel.cpp <==
/****************************************************************************
**
** Copyright (C) 2025 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "propertyeditordynamicpropertiesproxymodel.h"

#include <dynamicpropertiesmodel.h>

#include <propertyeditorview.h>

namespace QmlDesigner {

PropertyEditorDynamicPropertiesProxyModel::PropertyEditorDynamicPropertiesProxyModel(QObject *parent)
    : DynamicPropertiesProxyModel(parent)
{
    if (PropertyEditorView::instance())
        initModel(PropertyEditorView::instance()->dynamicPropertiesModel());
}

void PropertyEditorDynamicPropertiesProxyModel::registerDeclarativeType()
{
    DynamicPropertiesProxyModel::registerDeclarativeType();
    qmlRegisterType<PropertyEditorDynamicPropertiesProxyModel>("HelperWidgets", 2, 0, "PropertyEditorDynamicPropertiesModel");
}

} // namespace QmlDesigner

==> qt-creator-opensource-src-20.0.0-beta1.zip: qt-creator-opensource-src-20.0.0-beta1/src/plugins/qmldesigner/components/propertyeditor/propertyeditordynamicpropertiesproxymodel.cpp <==
/****************************************************************************
**
** Copyright (C) 2025 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "propertyeditordynamicpropertiesproxymodel.h"

#include "propertyeditortracing.h"

#include <dynamicpropertiesmodel.h>

#include <propertyeditorview.h>

namespace QmlDesigner {

using QmlDesigner::PropertyEditorTracing::category;

PropertyEditorDynamicPropertiesProxyModel::PropertyEditorDynamicPropertiesProxyModel(QObject *parent)
    : DynamicPropertiesProxyModel(parent)
{
    NanotraceHR::Tracer tracer{"property editor dynamic properties proxy model constructor",
                               category()};

    if (PropertyEditorView::instance())
        initModel(PropertyEditorView::instance()->dynamicPropertiesModel());
}

void PropertyEditorDynamicPropertiesProxyModel::registerDeclarativeType()
{
    NanotraceHR::Tracer tracer{
        "property editor dynamic properties proxy model register declarative type", category()};

    DynamicPropertiesProxyModel::registerDeclarativeType();
    qmlRegisterType<PropertyEditorDynamicPropertiesProxyModel>("HelperWidgets", 2, 0, "PropertyEditorDynamicPropertiesModel");
}

} // namespace QmlDesigner
